@@ -1,21 +1,15 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 ###################################################################################
 #
 # Pandora FMS Plugin functions library for Python
 #
-#  (c) A. Kevin Rojas <kevin.rojas@pandorafms.com>
-# 
-# Requirements:
-#  Library              Centos package
-#  -------              --------------
-#  LWP::UserAgent       perl-libwww-perl ??????????????????????????
+#  (c)  A. Kevin Rojas <kevin.rojas@pandorafms.com>
+#       Rafael Ameijeiras <rafael.ameijeiras@pandorafms.com>
 # 
 ###################################################################################
-# -*- coding: utf-8 -*-
 ## IMPORTS
 
-#import pysnmp 
-#import  pysnmp.hlapi
-#from os import name as ostype
 import json 
 import sys
 import os
@@ -26,8 +20,6 @@ from requests.auth import HTTPBasicAuth
 from requests.auth import HTTPDigestAuth
 from requests.sessions import Session
 
-## IMPORTS
-
 #########################################################################################
 # Agent class
 #########################################################################################
@@ -301,7 +293,7 @@ def write_xml(xml, agent_name, data_dir="/var/spool/pandora/data_in/"):
     - agent_name (str): agent name for the xml and file name.
     - data_dir (str): folder in which the file will be created."""
     Utime = datetime.now().strftime('%s')
-    data_file = "%s%s.%s.data" %(str(data_dir),agent_name,str(Utime))
+    data_file = "%s/%s.%s.data" %(str(data_dir),agent_name,str(Utime))
     try:
         with open(data_file, 'x') as data:
             data.write(xml)
@@ -417,7 +409,7 @@ def parse_csv_file(file, separator=';', count_parameters=None, debug=False) -> l
     - debug: print errors on lines
 
     Returns:
-    - arr: containing list whit all csv parameters.
+    - List: containing a list for of values for each csv line.
     """
     csv_arr = []
     try:
@@ -436,6 +428,7 @@ def parse_csv_file(file, separator=';', count_parameters=None, debug=False) -> l
         return csv_arr
     except Exception as e:
         print (f"{type(e).__name__}: {e}")
+        return 1
 
 #########################################################################################
 # URL calls
@@ -550,3 +543,12 @@ if __name__ == '__main__':
     # Send datafile file 
     if test_agent[1] is not None:
         tentacle_xml(test_agent[1], tentacle_conf, debug=0)
+
+    # test example translate macros
+    macros = {
+        '_test_': 'Prueba',
+        '_agent_name_':'pandora_agent'
+    }
+
+    string = '_test_ macro translator to agente _agent_name_'
+    print (translate_macros(macros, string))
\ No newline at end of file
